@@ -1,15 +1,16 @@
 from sys import argv
+from .py2md import Py2MD
 
 def main():
     if len(argv) == 1:
         print('Specify a .py file to run and create a .py.md output file.')
-        print('Use --debug to debug py2md process.')
-        return
-    
-    from .py2md import Py2MD
-    if argv[1][-3:] == '.py':
+        print('Use -debug to debug py2md process.')
+        print('Use -nocode to omit code blocks from output.')
+        print('Use -nohead to omit cell headers from output.')
+        print('Use -inline to make images internal to the output.')
+        print('Use -mplpng to make create png rather than svg images.')
+    elif argv[1][-3:] == '.py':
         py2md = Py2MD(argv[1])
-        
         nocode, nohead, inline, debug, mplpng = False, False, False, False, False
         for arg in argv[2:]:
             if arg == '-nocode':
@@ -22,7 +23,6 @@ def main():
                 debug = True
             elif arg == '-mplpng':
                 mplpng = True
-        
         py2md.run(mplpng)
         if len(argv) > 2:
             if argv[2] == '-debug':
@@ -30,3 +30,5 @@ def main():
         if debug:
             py2md.print_cells()
         py2md.write_file(inline, nocode, nohead)
+    else:
+        print('A python .py file needs to be supplied as the first argument.')
