@@ -1,29 +1,29 @@
-from numpy.matlib import matrix
+from typing import List
+from .mdobject import MDObject
 
-class MDMatrix(object):
+class MDMatrix(MDObject):
     label = None
     matrix = None
     frmstr = None
-    def __init__(self, label: str, matrix: matrix, frmstr: str):
+    def __init__(self, label: str, matrix: List[List[object]], frmstr: str):
         self.label = label
         self.matrix = matrix
         self.frmstr = frmstr
     def __str__(self):
-        mdstr = '$$\n'
+        mdstr = '\n$$\n'
         mdstr += '{:s} = \n'.format(self.label)
         mdstr += '\\begin{bmatrix}\n'
         shp = self.matrix.shape
-        for i in range(shp[0]):
-            for j in range(shp[1]):
-                value = self.matrix[i, j]
+        for i in range(len(self.matrix)):
+            row = self.matrix[i]
+            for j in range(len(row)):
+                value = self.matrix[i][j]
                 mdstr += value.__format__(self.frmstr)
-                if j == shp[1]-1:
+                if j == len(row)-1:
                     mdstr += ' \\\\\n'
                 else:
                     mdstr += ' && '
         mdstr += '\\end{bmatrix}\n$$\n'
         return mdstr
-    def _repr_markdown_(self):
-        return self.__str__()
     def __repr__(self):
-        return '<MDMatrix>'
+        return f'<MDMatrix: {self.label:s}>'
